"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActivatableLoggerImpl = void 0;
const moment_1 = __importDefault(require("moment"));
const lodash_1 = __importDefault(require("lodash"));
const noopTaggedLogger = {
    log(level, ...args) { },
    debug(...args) { },
    info(...args) { },
    warn(...args) { },
    error(...args) { },
    profile(...args) { },
};
class ActivatableLoggerImpl {
    constructor() {
        this.enabled = false;
        this.loggingFunction = console.info;
    }
    init(enabled, loggingFunction) {
        const config = require('./config').config;
        this.enabled = enabled;
        this.loggingFunction = loggingFunction || console.info;
    }
    tag(...tags) {
        if (this.enabled) {
            const loggingFunction = this.loggingFunction;
            return {
                log(level, ...args) {
                    const timeStr = (0, moment_1.default)().format('YYYY-MM-DD HH:mm:ss');
                    const levelStr = level.toUpperCase();
                    const tagsStr = tags ? '[' + lodash_1.default.join(tags, ', ') + ']' : '';
                    const messagePrefix = `${timeStr} ${levelStr} - ${tagsStr}`;
                    // Make sure to only replace %s, etc. in real log message
                    // but not in tags.
                    const escapedMessagePrefix = messagePrefix.replace(/%/g, '%%');
                    let message = '';
                    if (args && lodash_1.default.isString(args[0])) {
                        message = args[0];
                        args.shift();
                    }
                    const logStr = message
                        ? `${escapedMessagePrefix} ${message}`
                        : escapedMessagePrefix;
                    loggingFunction(logStr, ...args);
                },
                debug(...args) {
                    this.log('debug', ...args);
                },
                info(...args) {
                    this.log('info', ...args);
                },
                warn(...args) {
                    this.log('warn', ...args);
                },
                error(...args) {
                    this.log('error', ...args);
                },
                profile(...args) {
                    this.log('profile', ...args);
                },
            };
        }
        else {
            return noopTaggedLogger;
        }
    }
}
exports.ActivatableLoggerImpl = ActivatableLoggerImpl;
exports.default = new ActivatableLoggerImpl();
//# sourceMappingURL=logger.js.map